@@ -12,7 +12,7 @@
 class testBasic : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void testAlwaysSuccessful();
 };
 
