@@ -14,7 +14,7 @@
 class testKBlocksGameLogic : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void test_hasSingleGames();
 };
 
