@@ -17,7 +17,7 @@
 class testViewScene : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void test_settingsShouldBeUpdatedInViewAndScene();
 };
 
