@@ -22,12 +22,12 @@ class KBlocksAnimDrop : public QObject
 
 public:
     KBlocksAnimDrop(const QList<SvgItemInterface *> &items, int duration, QTimeLine::Direction direction);
-    ~KBlocksAnimDrop();
+    ~KBlocksAnimDrop() override;
 
-signals:
+Q_SIGNALS:
     void animationFinished();
 
-private slots:
+private Q_SLOTS:
     void valueChanged(qreal value);
     void endAnimation();
 
