@@ -22,12 +22,12 @@ class KBlocksView : public QGraphicsView
 
 public:
     explicit KBlocksView(SceneInterface *scene, QWidget *parent = nullptr);
-    ~KBlocksView();
+    ~KBlocksView() override;
 
-signals:
+Q_SIGNALS:
     void focusEvent(bool flag);
 
-public slots:
+public Q_SLOTS:
     void settingsChanged();
 
 protected:
