@@ -22,7 +22,7 @@ public:
           mpGameLogic(gameLogic)
     {
     }
-    virtual ~MockScene() = default;
+    ~MockScene() override = default;
 
 public:
     void createGameItemGroups(int, bool) override {}
@@ -42,7 +42,7 @@ public:
     void pauseGame(bool, bool) override {}
     void addScore(int, int) override {}
 
-public slots:
+public Q_SLOTS:
     void playMoveSound() override {}
     void playDropSound() override {}
 
